@@ -80,92 +80,98 @@
 #' }
 make_epicontacts <- function(linelist, contacts, id = 1L, from = 1L, to = 2L,
                              directed = FALSE){
-    ## We read data from linelist, which needs to contain at least one case, and
-    ## contacts. Sanity checks will include standard class
-    ## and dimensionality checks, as well as uniqueness of IDs in the line list,
-    ## and enforcing 'character' type for the unique IDs, and naming the case ID
-    ## field 'id'. We also reorder data so that the first column of 'linelist'
-    ## is 'id', and the first two columns of 'contacts' are 'from' and 'to'
+  ## We read data from linelist, which needs to contain at least one case, and
+  ## contacts. Sanity checks will include standard class
+  ## and dimensionality checks, as well as uniqueness of IDs in the line list,
+  ## and enforcing 'character' type for the unique IDs, and naming the case ID
+  ## field 'id'. We also reorder data so that the first column of 'linelist'
+  ## is 'id', and the first two columns of 'contacts' are 'from' and 'to'
 
-    ## process linelist ##
-    ## checks
+  ## process linelist ##
+  ## checks
 
-    if (is.null(linelist)) {
-        stop("linelist is NULL")
-    }
+  if (is.null(linelist)) {
+    stop("linelist is NULL")
+  }
 
-    if (is.vector(linelist) &&
+  if (is.vector(linelist) &&
         length(linelist) == 1L &&
         is.na(linelist)) {
-        stop("linelist is NA")
-    }
+    stop("linelist is NA")
+  }
 
-    linelist <- as.data.frame(linelist)
+  linelist <- as.data.frame(linelist, stringsAsFactors = FALSE)
 
-    if (nrow(linelist) < 1L) {
-        stop("linelist should have at least one row")
-    }
+  if (nrow(linelist) < 1L) {
+    stop("linelist should have at least one row")
+  }
 
-    linelist[,id] <- as.character(linelist[,id])
-    if (sum(temp <- duplicated(linelist[,id]))>0) {
-        msg <- paste(linelist[temp,id], collapse=" ")
-        stop("Duplicated IDs detected in the linelist; culprits are: ", msg)
-    }
+  linelist[,id] <- linelist[,id]
+  if (sum(temp <- duplicated(linelist[,id]))>0) {
+    msg <- paste(linelist[temp,id], collapse=" ")
+    stop("Duplicated IDs detected in the linelist; culprits are: ", msg)
+  }
 
 
-    ## reordering
+  ## convert factors to characters
+  if (is.factor(linelist$id)) linelist$id <- as.character(linelist$id)
+  if (is.factor(linelist$from)) linelist$from <- as.character(linelist$from)
+  if (is.factor(linelist$to)) linelist$to <- as.character(linelist$to)
 
-    if (is.character(id)) {
-        id <- match(id, names(linelist))
-    }
-    names(linelist)[id] <- "id"
-    linelist <- subset(linelist, select = c(id, setdiff(seq_len(ncol(linelist)), id)))
+  ## reordering
+  if (is.character(id)) {
+    id <- match(id, names(linelist))
+  }
+  names(linelist)[id] <- "id"
+  linelist <- subset(linelist,
+                     select = c(id, setdiff(seq_len(ncol(linelist)), id)))
 
 
 
-    ## process contacts ##
-    ## checks
+  ## process contacts ##
+  ## checks
 
-    if (is.null(contacts)) {
-        stop("contacts is NULL")
-    }
+  if (is.null(contacts)) {
+    stop("contacts is NULL")
+  }
 
-    if (is.vector(contacts) &&
+  if (is.vector(contacts) &&
         length(contacts) == 1L &&
         is.na(contacts)) {
-        stop("contacts is NA")
-    }
+    stop("contacts is NA")
+  }
 
-    contacts <- as.data.frame(contacts)
+  contacts <- as.data.frame(contacts)
 
-    if(nrow(contacts) < 1L) {
-        stop("contacts should have at least one row")
-    }
-    if (ncol(contacts) < 2L) {
-        stop("contacts should have at least two columns")
-    }
+  if(nrow(contacts) < 1L) {
+    stop("contacts should have at least one row")
+  }
+  if (ncol(contacts) < 2L) {
+    stop("contacts should have at least two columns")
+  }
 
-    ## reordering
-    if (is.character(from)) {
-        from <- match(from, names(contacts))
-    }
-    if (is.character(to)) {
-        to <- match(to, names(contacts))
-    }
-    names(contacts)[c(from,to)] <- c("from", "to")
-    contacts <- contacts[, c(from, to, setdiff(seq_len(ncol(contacts)), c(from,to)))]
+  ## reordering
+  if (is.character(from)) {
+    from <- match(from, names(contacts))
+  }
+  if (is.character(to)) {
+    to <- match(to, names(contacts))
+  }
+  names(contacts)[c(from,to)] <- c("from", "to")
+  contacts <- contacts[, c(from, to, setdiff(seq_len(ncol(contacts)), c(from,to)))]
 
-    ## ensure that from and to are not stored as factor
-    if (is.factor(contacts$from)) {
-        contacts$from <- as.character(contacts$from)
-    }
-    if (is.factor(contacts$to)) {
-        contacts$to <- as.character(contacts$to)
-    }
+  ## ensure all IDs are stored as characters if one is
+  if (is.character(linelist$id) ||
+        is.character(contacts$from) ||
+        is.character(contacts$to)) {
+    linelist$id <- as.character(linelist$id)
+    contacts$from <- as.character(contacts$from)
+    contacts$to <- as.character(contacts$to)
+  }
 
-    ## Build final output
-    out <- list(linelist = linelist, contacts = contacts, directed = directed)
+  ## Build final output
+  out <- list(linelist = linelist, contacts = contacts, directed = directed)
 
-    class(out) <- c("epicontacts")
-    return(out)
+  class(out) <- c("epicontacts")
+  return(out)
 }
