@@ -38,6 +38,6 @@ rokupafuneral <- subset(x,
 ## ------------------------------------------------------------------------
 summary(rokupafuneral)
 
-## ------------------------------------------------------------------------
-plot(rokupafuneral, y = "outcome")
+## ---- eval = F-----------------------------------------------------------
+#  plot(rokupafuneral, y = "outcome")
 
